Code tables from Michael Everson at Evertype
--------------------------------------------

These are provided at https://www.evertype.com/standards/mappings/, which carries the following notice:

> The following tables are mappings from the code tables I devised for the Mac OS and PC platforms to Unicode. With few exceptions, these code tables were not blessed by Apple or Microsoft, though various private > vendors have made fonts conforming to them, and there are many users of my Mac OS WorldScript utilities out there.
